@@ -23,26 +23,25 @@ import java.util.List;
 import com.google.common.collect.ImmutableList;
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Field;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.NormDiscrete;
 
 public class BooleanFeature extends CategoricalFeature implements HasDerivedName {
 
 	public BooleanFeature(PMMLEncoder encoder, Field<?> field){
-		this(encoder, field.getName());
+		this(encoder, field.requireName());
 	}
 
 	public BooleanFeature(PMMLEncoder encoder, Feature feature){
 		this(encoder, feature.getName());
 	}
 
-	public BooleanFeature(PMMLEncoder encoder, FieldName name){
+	public BooleanFeature(PMMLEncoder encoder, String name){
 		super(encoder, name, DataType.BOOLEAN, BooleanFeature.VALUES);
 	}
 
 	@Override
-	public FieldName getDerivedName(){
-		return FieldName.create((getName()).getValue() + "=true");
+	public String getDerivedName(){
+		return getName() + "=true";
 	}
 
 	@Override
