@@ -20,6 +20,7 @@ package org.jpmml.converter;
 
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Field;
+import org.dmg.pmml.OpType;
 
 public class ContinuousLabel extends ScalarLabel {
 
@@ -35,6 +36,11 @@ public class ContinuousLabel extends ScalarLabel {
 		super(name, dataType);
 	}
 
+	@Override
+	public OpType getOpType(){
+		return OpType.CONTINUOUS;
+	}
+
 	@Override
 	public ContinuousLabel toRenamedLabel(String name){
 		return new ContinuousLabel(name, getDataType());
