@@ -22,7 +22,6 @@ import java.util.LinkedHashMap;
 import java.util.Map;
 
 import org.dmg.pmml.DataType;
-import org.dmg.pmml.FieldName;
 
 public class RExpUtil {
 
@@ -72,11 +71,6 @@ public class RExpUtil {
 		return result;
 	}
 
-	static
-	public FieldName makeName(FieldName name){
-		return FieldName.create(makeName(name.getValue()));
-	}
-
 	static
 	public String makeName(String string){
 		StringBuilder sb = new StringBuilder();
