@@ -38,11 +38,6 @@ public class RIntegerVector extends RNumberVector<Integer> {
 
 	@Override
 	public DataType getDataType(){
-
-		if(isFactor()){
-			return DataType.STRING;
-		}
-
 		return DataType.INTEGER;
 	}
 
@@ -80,48 +75,5 @@ public class RIntegerVector extends RNumberVector<Integer> {
 		return Lists.transform(Ints.asList(this.values), function);
 	}
 
-	public boolean isFactor(){
-		return hasAttribute("levels");
-	}
-
-	public RStringVector getLevels(){
-		return getStringAttribute("levels");
-	}
-
-	public List<String> getLevelValues(){
-		RStringVector levels = getLevels();
-
-		return levels.getValues();
-	}
-
-	public String getFactorValue(int index){
-		RStringVector levels = getLevels();
-
-		Integer value = getValue(index);
-		if(value == null){
-			return null;
-		}
-
-		return levels.getValue(value - 1);
-	}
-
-	public List<String> getFactorValues(){
-		List<Integer> values = getValues();
-		List<String> levelValues = getLevelValues();
-
-		Function<Integer, String> function = new Function<Integer, String>(){
-
-			@Override
-			public String apply(Integer value){
-
-				if(value == null){
-					return null;
-				}
-
-				return levelValues.get(value - 1);
-			}
-		};
-
-		return Lists.transform(values, function);
-	}
+	public static final RIntegerVector EMPTY = new RIntegerVector(new int[0], null);
 }
\ No newline at end of file
