@@ -25,7 +25,7 @@ import org.dmg.pmml.DataType;
 import org.dmg.pmml.OpType;
 import org.jpmml.converter.ContinuousLabel;
 import org.jpmml.converter.Label;
-import org.jpmml.converter.PMMLEncoder;
+import org.jpmml.converter.ModelEncoder;
 
 abstract
 public class Regression extends ObjFunction {
@@ -35,7 +35,7 @@ public class Regression extends ObjFunction {
 	}
 
 	@Override
-	public Label encodeLabel(String targetName, List<?> targetCategories, PMMLEncoder encoder){
+	public Label encodeLabel(String targetName, List<?> targetCategories, ModelEncoder encoder){
 
 		if(targetCategories != null){
 			throw new IllegalArgumentException("Regression requires zero target categories");
